Module config

Module config 

TOML config loader with auto-create from template.

load_toml_config reads a TOML file and deserializes it into a typed config struct. If the file doesn’t exist and a template is provided, it creates the file first.

Re-exports

pub use loader::FieldError;
pub use loader::load_toml_config;
pub use loader::validate_config;
pub use template::default_config_template;

Modules

loader
TOML config loader with auto-create from template.
template
Default config template generator.