validate_config

Function validate_config 

pub fn validate_config<T: DeserializeOwned>(
    toml_str: &str,
) -> Result<T, Vec<FieldError>>
Validate a TOML config string and return structured field-level errors.

On success, returns the parsed config. On failure, returns a vec of FieldError instead of a raw string error, making it possible to display targeted error messages per field.