pub fn fetch() -> Result<ModelsDevPayload>Expand description
Fetch and parse the catalog from the default models.dev endpoint (no cache).
pub fn fetch() -> Result<ModelsDevPayload>Fetch and parse the catalog from the default models.dev endpoint (no cache).