pub fn decay_importance(
conn: &Connection,
days: u64,
factor: f64,
floor: f64,
) -> Result<u64>Expand description
Gradually decay importance for nodes not accessed in days.
Reduces importance by factor (e.g. 0.9 = 10% decay).
Nodes with importance at or below floor are not decayed further.
Nodes with the pinned tag are protected from decay.
Returns the number of nodes decayed.