pub struct AnthropicClient { /* private fields */ }Expand description
Async LLM client for the Anthropic Messages API.
Implementations
Sourceimpl AnthropicClient
impl AnthropicClient
Sourcepub fn new(config: &ModelConfig) -> Result<Self>
pub fn new(config: &ModelConfig) -> Result<Self>
Create a new client using credentials from the environment variable in config.
Sourcepub fn from_key(
model: impl Into<String>,
api_key: impl Into<String>,
) -> Result<Self>
pub fn from_key( model: impl Into<String>, api_key: impl Into<String>, ) -> Result<Self>
Create a new client with an explicit API key, using the default Anthropic base URL.
Returns a KernelError::Config if the HTTP client (with its connect /
total timeouts) cannot be built, rather than silently falling back to a
timeout-less reqwest::Client::default().