pub fn serialize_catalog(providers: &[ServiceDescriptor]) -> Result<String>Expand description
Serialize a provider list back into the canonical catalog.json form
(pretty-printed, 2-space indent, trailing newline).
pub fn serialize_catalog(providers: &[ServiceDescriptor]) -> Result<String>Serialize a provider list back into the canonical catalog.json form
(pretty-printed, 2-space indent, trailing newline).