SearchProvider

Trait SearchProvider 

pub trait SearchProvider: Send + Sync {
    // Required methods
    fn name(&self) -> &'static str;
    fn search(&self, query: &str, limit: usize) -> Result<Vec<SearchResult>>;
}
Unified sync interface for search backends producing ranked results.

Required Methods

fn name(&self) -> &'static str

Human-readable backend name.

fn search(&self, query: &str, limit: usize) -> Result<Vec<SearchResult>>

Run a query, returning up to limit ranked results.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors