Node deduplication: prevent duplicate nodes by title within a time window.
Functions
- find_
duplicate - Find a node with the given title updated within
window_hours. - upsert_
node_ dedup - Write with deduplication. If a node with the same
titlewas written withinwindow_hours, return the existing ID instead. Otherwise, insert and return the new ID.