pub struct OpenAIClient { /* private fields */ }Expand description
Async LLM client for the OpenAI chat completions API.
Implementations
Sourceimpl OpenAIClient
impl OpenAIClient
Sourcepub fn new(config: &ModelConfig) -> Result<Self>
pub fn new(config: &ModelConfig) -> Result<Self>
Create a new client using credentials from the environment variable in config.
Sourcepub fn from_key(
model: impl Into<String>,
api_key: impl Into<String>,
) -> Result<Self>
pub fn from_key( model: impl Into<String>, api_key: impl Into<String>, ) -> Result<Self>
Create a new client with an explicit API key, using the default OpenAI base URL.
Returns a KernelError::Config if the HTTP client (with its connect /
total timeouts) cannot be built, rather than silently falling back to a
timeout-less reqwest::Client::default().
Example
use llm_kernel::llm::OpenAIClient;
let client = OpenAIClient::from_key("gpt-4o-mini", "sk-...")?;Sourcepub fn from_key_with_client(
model: impl Into<String>,
api_key: impl Into<String>,
client: Client,
) -> Self
pub fn from_key_with_client( model: impl Into<String>, api_key: impl Into<String>, client: Client, ) -> Self
Create from an explicit key and a shared reqwest::Client.
Prefer this over from_key when constructing multiple
clients in a hot path — the shared client reuses the underlying TCP
connection pool.
Sourcepub fn from_key_with_base_url(
model: impl Into<String>,
api_key: impl Into<String>,
base_url: impl Into<String>,
client: Client,
) -> Self
pub fn from_key_with_base_url( model: impl Into<String>, api_key: impl Into<String>, base_url: impl Into<String>, client: Client, ) -> Self
Create from an explicit key, a custom base URL, and a shared reqwest::Client.
Use this for OpenAI-compatible providers that are not the default OpenAI endpoint (DeepSeek, Groq, Ollama, LM Studio, custom gateways, …) when you already hold the key in memory and want to reuse a shared connection pool.